==> v0.1.9.tar.gz: wcs/wcs/__init__.py <==
from Defaults import *

try:
    from wcs_cfg import *
except ImportError:
    pass

import os
import lasso
import __builtin__

import storage
import gettext, locale

gettext.install('wcs')
_1 = _
__builtin__.__dict__['_'] = lambda x: unicode(_1(str(x)), 'utf-8').encode('iso-8859-1')
__builtin__.__dict__['N_'] = lambda x: x

from quixote import enable_ptl
from quixote.publish import Publisher
enable_ptl()

import misc

import errors
import sessions

from root import RootDirectory

class WcsPublisher(Publisher):
    def format_publish_error(self, exc):
        if isinstance(exc, errors.AccessError) and hasattr(exc, 'render'):
            return exc.render()
        return Publisher.format_publish_error(self, exc)

    def set_config(self):
        misc.reload_cfg()
        debug_cfg = misc.cfg.get('debug', {})
        self.logger.error_email = debug_cfg.get('error_email')
        self.config.display_exceptions = debug_cfg.get('display_exceptions')
        self.config.form_tokens = True


class WcsVHostPublisher(WcsPublisher):
    def try_publish(self, request):
        self.app_dir = os.path.join(APP_DIR, request.get_server().split(':')[0])
        if not os.path.exists(self.app_dir):
            os.mkdir(self.app_dir)
        self.set_config()
        return WcsPublisher.try_publish(self, request)


def create_publisher(publisher_class = WcsPublisher):
    publisher = publisher_class(RootDirectory(),
            session_cookie_name = 'wcs',
            session_cookie_path = '/')
    publisher.app_dir = APP_DIR
    publisher.data_dir = DATA_DIR
    if not os.path.exists(publisher.app_dir):
        os.mkdir(publisher.app_dir)
    publisher.set_session_manager(sessions.PickleSessionManager())
    publisher.set_config()
    return publisher

def create_vhost_publisher():
    return create_publisher(WcsVHostPublisher)

==> v0.3.9.tar.gz: wcs/wcs/__init__.py <==
from Defaults import *

try:
    from wcs_cfg import *
except ImportError:
    pass

import os
import lasso
import __builtin__

from sqlobject import *

import gettext, locale

gettext.install('wcs')
_1 = _
__builtin__.__dict__['_'] = lambda x: unicode(_1(str(x)), 'utf-8').encode('iso-8859-1')
__builtin__.__dict__['N_'] = lambda x: x

from quixote import enable_ptl
from quixote.publish import Publisher
enable_ptl()

import misc

import errors
import sessions

import anonylink
import categories
import consultationdef
import formdata
import formdef
import roles
import users

sqlobject_classes = [anonylink.AnonymityLink, categories.Category,
        roles.RoleEmail, roles.Role, users.NameIdentifier, users.User,
        formdef.FormField, formdef.FormDef,
        consultationdef.ConsultationField, consultationdef.Consultation,
        formdata.FormDataEvolution, formdata.FormData,
        sessions.SqlSession,
        ]

from root import RootDirectory

class WcsPublisher(Publisher):
    def format_publish_error(self, exc):
        if isinstance(exc, errors.AccessError) and hasattr(exc, 'render'):
            return exc.render()
        return Publisher.format_publish_error(self, exc)

    def set_config(self):
        misc.reload_cfg()
        debug_cfg = misc.cfg.get('debug', {})
        self.logger.error_email = debug_cfg.get('error_email')
        self.config.display_exceptions = debug_cfg.get('display_exceptions')
        self.config.form_tokens = True

    def set_connection(self):
        self.conn = connectionForURI('sqlite://%s/wcs.db' % self.app_dir)
        for klass in sqlobject_classes:
            klass.setConnection(self.conn)
            if not self.conn.tableExists(klass._table):
                klass.createTable()
                if hasattr(klass, 'initTable'):
                    klass.initTable()
                if hasattr(klass, 'migrateOldData'):
                    klass.migrateOldData()

class WcsVHostPublisher(WcsPublisher):
    def try_publish(self, request):
        self.app_dir = os.path.join(APP_DIR, request.get_server().split(':')[0])
        if not os.path.exists(self.app_dir):
            os.mkdir(self.app_dir)
        self.set_config()
        self.set_connection()
        return WcsPublisher.try_publish(self, request)


def create_publisher(publisher_class = WcsPublisher):
    publisher = publisher_class(RootDirectory(),
            session_cookie_name = 'wcs',
            session_cookie_path = '/')
    publisher.app_dir = APP_DIR
    publisher.data_dir = DATA_DIR
    if not os.path.exists(publisher.app_dir):
        os.mkdir(publisher.app_dir)
    publisher.set_session_manager(sessions.SqlSessionManager())
    publisher.set_config()
    publisher.set_connection()
    return publisher

def create_vhost_publisher():
    return create_publisher(WcsVHostPublisher)
